## Annotation Json Schemas
* [General info](#general-info)
* [Setup](#setup)

## General info
This project is SuperAnnotate annotations JSON schema generator.
	
## Setup
```
$ pip install superannotate_schemas
```

## Example
```
$ superannotate_schema validate <annotation_path>
$ superannotate_schema validate <annotation_path>, <annotation_path>
```
- To print validation report set --verbose True
- To store reports in the file set --report-path
